# CoreDotFinance
### Powerful Python financial data library
[![GitHup issues](https://img.shields.io/github/issues/CoreDotToday/CoreDotFinance)](https://github.com/CoreDotToday/CoreDotFinance/issues)
[![GitHub pull requests](https://img.shields.io/github/issues-pr/CoreDotToday/CoreDotFinance)](https://github.com/CoreDotToday/CoreDotFinance/pulls)
[![PyPI Latest Release](https://img.shields.io/static/v1?label=PyPI&message=1.0.2&color=orange)](https://pypi.org/project/coredotfinance/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
----------------------------

## 금융 데이터를 쉽고 빠르게!
**CoreDotFinance**는 [KRX](https://www.data.krx.co.kr)의 주식데이터 [Binance](https://www.binance.com)와의 가상화폐 데이터를 
쉽고 빠르게 파이썬 작업 환경에서 작업할 수 있도록 도와주는 파이썬 라이러리입니다. 

## 설치 방법
```sh
pip install coredotfinance
```

## 문서
공식문서 : [https://coredottoday.github.io/CoreDotFinance/](https://coredottoday.github.io/CoreDotFinance/)


## License
Apach License
